@@ -4,6 +4,7 @@
 import csv
 import os
 
+from .. import env
 from ..utils import support
 
 __all__ = ['odps_download_with_sql']
@@ -12,9 +13,9 @@ __all__ = ['odps_download_with_sql']
 def odps_download_with_sql(sql, save_path, connect=None, sep=',', tocache: bool = False):
     """通过SQL下载全量数据"""
     connect = connect or support.odps_connect()
-    save_path = os.path.join(tocache and support.CACHE_PROJECT_HOME or support.PROJECT_HOME, save_path)
+    save_path = os.path.join(tocache and env.CACHE_PROJECT_HOME or env.PROJECT_HOME, save_path)
     if sql.endswith('.sql'):
-        with open(os.path.join(support.PROJECT_HOME, sql), 'r') as f:
+        with open(os.path.join(env.PROJECT_HOME, sql), 'r') as f:
             fsql = f.read()
     else:
         fsql = sql
